/* Copyright (c) 2008, Sheng Guo, Li-San Wang and Junhyong Kim, University of
  Pennsylvania.  All Rights Reserved.
 
  You may not use this file except in compliance with the License
  located in the top directory of this distribution.  You may obtain
  a copy of the License at
 
      http://kim.bio.upenn.edu/software/index.shtml
 
  Unless required by applicable law or agreed to in writing, this
  software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
  CONDITIONS OF ANY KIND, either express or implied.  See the License
  for the specific language governing permissions and limitations
  under the License. 
*/


#ifndef PARAMETERS_H
#define PARAMETERS_H
#include <string>

using namespace std;

class Parameters{

public:

	Parameters();

	void display_version();
	void display_usage_short();
	void display_usage_long();
	void set_default_parameters();
	bool process_parameters(int, char**);
	void display_parameters();

	char *in_tre;		/*input: tree file in Newick format*/
	char *in_rna;		/*input: rna sequece with secondary structure*/

//	char *out_pfx;		/*output: prefix*/
//	char *out_nuc;		/*output: nucleotide*/
//	char *out_sec;		/*output: scondary structure in bracket format*/
//	char *out_sid;		/*output: sequence sid*/
//	char *out_tre;		/*output: scaled tree*/
//	char *out_pos;		/*output: nucleotide position in 'true' alignment*/

//	char out_pfx[1000];		/*output: prefix*/
//	char out_nuc[1000];		/*output: nucleotide*/
//	char out_sec[1000];		/*output: scondary structure in bracket format*/
//	char out_sid[1000];		/*output: sequence sid*/
//	char out_tre[1000];		/*output: scaled tree*/
//	char out_pos[1000];		/*output: nucleotide position in 'true' alignment*/

	string out_pfx;
	string out_nuc;
	string out_sec;
	string out_sid;
	string out_tre;
	string out_pos;	

	double N;		/*population size*/
	double bsf;		/*branch scaling factor*/
	double E_opt;		/*optimal folding energy*/
	double kappa;		/*ratio of indel to substitution*/
	double alpha;		/*regularization factor for energy change on fitness change*/
	double gamma_shape;	/*shape parameter for gamma distribution*/
	double gamma_rate;	/*rate parameter for gamma distribution*/
	double gamma_maxweight; /*maximal weight in a gamma distribution*/
	int    distr_pool_size; /*number of RNAs used to construct the distribution of substitution rate*/
	double global_DeltaE;   /*min{DeltaE}: maximal free energy change between an advantageous mutant and its wild type*/
	bool   fixed_global_DeltaE; /*whether a fixed min{DeltaE} is used */

	bool verbose;	/*display simulation progress*/

	bool validate_parameter(char, double);
	bool validate_parameter(char, char *);

};

#endif
