/* Copyright (c) 2008, Sheng Guo, Li-San Wang and Junhyong Kim, University of
  Pennsylvania.  All Rights Reserved.
 
  You may not use this file except in compliance with the License
  located in the top directory of this distribution.  You may obtain
  a copy of the License at
 
      http://kim.bio.upenn.edu/software/index.shtml
 
  Unless required by applicable law or agreed to in writing, this
  software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
  CONDITIONS OF ANY KIND, either express or implied.  See the License
  for the specific language governing permissions and limitations
  under the License. 
*/


/*******************************************************************************************
	class RootedTree, created by RootedTreeParser(), it provides various manipulating functions			
********************************************************************************************/
#ifndef ROOTEDTREE_H
#define ROOTEDTREE_H

#include "RootedTreeNode.h"
#include "RootedTreeParser.h"

#include <string>
#include <vector>
#include <stack>
#include <cassert>
#include <cstdio>

class RootedTree{

private:
	RootedTreeNode * root;
	
public:
	RootedTree();	
	~RootedTree();
	void bystr(string &);	// parse a string to get a tree structure
	void setRoot(RootedTreeNode *);
	RootedTreeNode * getRoot() const;
	string nexus(int intnode = 1) const; //return nexus tree
	void contractZeroEdgeLength();
	void suppressSISO();
	RootedTree * copy() const;
	vector<RootedTreeNode *> leafset()const;
	vector<RootedTreeNode *> circularorder() const;
	vector<string> nodelist_to_labellist(vector<RootedTreeNode *> ) const;
	vector<RootedTreeNode *> getAllNodes()const;
	double minHeight() const;
	double maxHeight() const;
	void scale(double);	//change el of non-root node
	bool isBinary() const;
	bool isUltrametic() const;
};

#endif
//END_OF_FILE
